function v=compute_normal_surge_so_factor(tau,iid,a)
% Computes second-order reduction factor
% Script automatically generated by fitnlfac100_02.m
% Inputs : 
% tau            = normal component of wind stress (N/m2)
% iid            = shelf number (-)
% a              = dean slope (-)

beta( 1 )= 6.3530e-01 ;
beta( 2 )= 3.4011e-01 ;
beta( 3 )= 9.0503e-03 ;
beta( 4 )= -1.2743e+00 ;
beta( 5 )= 1.6920e-03 ;
beta( 6 )= 2.4149e-08 ;

v=1-max(tau-beta(1),0.0).^beta(2) .* (a+beta(3)).^beta(4) .* (beta(5)-beta(6)*(iid));
